@@ -25,7 +25,7 @@ class MetaDataMixin(LargeImageMixinBase):
     )
     @action(detail=False)
     def metadata(self, request: Request, pk: int = None) -> Response:
-        source = self.get_tile_source(request, pk)
+        source = self.get_tile_source(request, pk, style=False)
         metadata = tilesource.get_metadata(source)
         return Response(metadata)
 
@@ -36,7 +36,7 @@ class MetaDataMixin(LargeImageMixinBase):
     )
     @action(detail=False)
     def internal_metadata(self, request: Request, pk: int = None) -> Response:
-        source = self.get_tile_source(request, pk)
+        source = self.get_tile_source(request, pk, style=False)
         metadata = tilesource.get_internal_metadata(source)
         return Response(metadata)
 
@@ -47,7 +47,7 @@ class MetaDataMixin(LargeImageMixinBase):
     )
     @action(detail=False)
     def bands(self, request: Request, pk: int = None) -> Response:
-        source = self.get_tile_source(request, pk)
+        source = self.get_tile_source(request, pk, style=False)
         metadata = source.getBandInformation()
         return Response(metadata)
 
@@ -59,7 +59,7 @@ class MetaDataMixin(LargeImageMixinBase):
     @action(detail=False)
     def band(self, request: Request, pk: int = None) -> Response:
         band = int(request.query_params.get('band', 1))
-        source = self.get_tile_source(request, pk)
+        source = self.get_tile_source(request, pk, style=False)
         metadata = source.getOneBandInformation(band)
         return Response(metadata)
 
